import { Observable } from 'rxjs';
import { TransferInterface } from '../interfaces/transfer.interface';
import { FileManagerOptionsInterface } from '../interfaces/file-manager-options.interface';
import { FileManagerInterface } from '../interfaces/file-manager.interface';
import { FileObject } from './file-object.class';
export declare class FileManager implements FileManagerInterface {
    options: FileManagerOptionsInterface;
    private _id;
    private _protocol;
    private _uploader;
    private _fileElement;
    private _file;
    private _speedDefault;
    private _progress$;
    private _speed$;
    private _isUploading;
    private _isUploaded;
    private _isSuccess;
    private _isCancel;
    private _isError;
    private _imageLoad;
    private _fileActive;
    private _response;
    set protocol(_protocol: any);
    get id(): string;
    get progressPercent$(): Observable<number>;
    get progress$(): Observable<any>;
    get progress(): any;
    get element(): any;
    get object(): FileObject;
    get name(): string;
    get type(): string;
    get date(): Date | null;
    get size(): number | null;
    get inQueue(): boolean;
    get response(): any;
    get success(): boolean;
    get error(): boolean;
    /**
     * Creates an instance of FileManager.
     *
     * @memberOf FileManager
     */
    constructor(file: any, options?: FileManagerOptionsInterface, uploader?: TransferInterface<FileManagerInterface>);
    /**
     * Bind uploader to FileManager
     *
     * @memberOf FileManager
     */
    bindUploader(uploader: TransferInterface<FileManagerInterface>): void;
    /**
     * Bind options to FileManager
     *
     * @memberOf FileManager
     */
    bindOptions(options: FileManagerOptionsInterface): void;
    /**
     * Return uploader if exists else throw error
     *
     * @memberOf FileManager
     */
    getUploader(): TransferInterface<FileManagerInterface>;
    /**
     * Start uploading this file
     *
     *
     * @memberOf FileManager
     */
    upload(): void;
    /**
     * Cancel upload process from this file
     *
     *
     * @memberOf FileManager
     */
    cancel(): void;
    _cancel(): void;
    /**
     * Remove this FileManger from uploader queue
     *
     *
     * @memberOf FileManager
     */
    remove(): void;
    isUploaded(): boolean;
    isUploading(): boolean;
    canUpload(): boolean;
    handleImageLoad(): void;
    /**
     * Overwrite functions
     */
    onBeforeUpload(): void;
    onProgressSpeed(speed: any): void;
    onProgress(progress: number): void;
    onSuccess(response: any, status: number, headers: any): void;
    onError(response: any, status: number, headers: any): void;
    /**
     *  Internal functions
     */
    _onBeforeUpload(): void;
    _onProgressFileSpeed(speed: any): void;
    _onProgress(progress: number): void;
    _onSuccess(response: any, status: number, headers: any): void;
    _onError(response: any, status: number, headers: any): void;
    private _setFileActive;
}
